# pypetwalk

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pypetwalk?logo=python)
[![codecov](https://codecov.io/gh/p0l0/pypetwalk/branch/main/graph/badge.svg?token=V5C2O6SK2O)](https://codecov.io/gh/p0l0/pypetwalk)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=f8b424)](https://github.com/pre-commit/pre-commit)
![Build Pipeline](https://github.com/p0l0/pypetwalk/actions/workflows/ci.yml/badge.svg?branch=main)

`pypetwalk` is a Python 3 (>= 3.9) library to communicate with the petWALK.control module.

It is intended to be used in a custom_component for [Home Assistant](https://www.home-assistant.io/).